@@ -5,15 +5,16 @@ import os
 import sys
 import time
 import traceback
-import numpy as np
 from random import randrange
 
+import numpy as np
 import torch
-from TTS.utils.arguments import parse_arguments, process_args
+
 # DISTRIBUTED
 from torch.nn.parallel import DistributedDataParallel as DDP_th
 from torch.utils.data import DataLoader
 from torch.utils.data.distributed import DistributedSampler
+
 from TTS.tts.datasets.preprocess import load_meta_data
 from TTS.tts.datasets.TTSDataset import MyDataset
 from TTS.tts.layers.losses import SpeedySpeechLoss
@@ -24,10 +25,10 @@ from TTS.tts.utils.speakers import parse_speakers
 from TTS.tts.utils.synthesis import synthesis
 from TTS.tts.utils.text.symbols import make_symbols, phonemes, symbols
 from TTS.tts.utils.visual import plot_alignment, plot_spectrogram
+from TTS.utils.arguments import parse_arguments, process_args
 from TTS.utils.audio import AudioProcessor
 from TTS.utils.distribute import init_distributed, reduce_tensor
-from TTS.utils.generic_utils import (KeepAverage, count_parameters,
-                                     remove_experiment_folder, set_init_dict)
+from TTS.utils.generic_utils import KeepAverage, count_parameters, remove_experiment_folder, set_init_dict
 from TTS.utils.radam import RAdam
 from TTS.utils.training import NoamLR, setup_torch_training_env
 
@@ -44,10 +45,9 @@ def setup_loader(ap, r, is_val=False, verbose=False):
             compute_linear_spec=False,
             meta_data=meta_data_eval if is_val else meta_data_train,
             ap=ap,
-            tp=c.characters if 'characters' in c.keys() else None,
-            add_blank=c['add_blank'] if 'add_blank' in c.keys() else False,
-            batch_group_size=0 if is_val else c.batch_group_size *
-            c.batch_size,
+            tp=c.characters if "characters" in c.keys() else None,
+            add_blank=c["add_blank"] if "add_blank" in c.keys() else False,
+            batch_group_size=0 if is_val else c.batch_group_size * c.batch_size,
             min_seq_len=c.min_seq_len,
             max_seq_len=c.max_seq_len,
             phoneme_cache_path=c.phoneme_cache_path,
@@ -56,7 +56,10 @@ def setup_loader(ap, r, is_val=False, verbose=False):
             enable_eos_bos=c.enable_eos_bos_chars,
             use_noise_augment=not is_val,
             verbose=verbose,
-            speaker_mapping=speaker_mapping if c.use_speaker_embedding and c.use_external_speaker_embedding_file else None)
+            speaker_mapping=speaker_mapping
+            if c.use_speaker_embedding and c.use_external_speaker_embedding_file
+            else None,
+        )
 
         if c.use_phonemes and c.compute_input_seq_cache:
             # precompute phonemes to have a better estimate of sequence lengths.
@@ -71,9 +74,9 @@ def setup_loader(ap, r, is_val=False, verbose=False):
             collate_fn=dataset.collate_fn,
             drop_last=False,
             sampler=sampler,
-            num_workers=c.num_val_loader_workers
-            if is_val else c.num_loader_workers,
-            pin_memory=False)
+            num_workers=c.num_val_loader_workers if is_val else c.num_loader_workers,
+            pin_memory=False,
+        )
     return loader
 
 
@@ -95,9 +98,7 @@ def format_data(data):
             speaker_c = data[8]
         else:
             # return speaker_id to be used by an embedding layer
-            speaker_c = [
-                speaker_mapping[speaker_name] for speaker_name in speaker_names
-            ]
+            speaker_c = [speaker_mapping[speaker_name] for speaker_name in speaker_names]
             speaker_c = torch.LongTensor(speaker_c)
     else:
         speaker_c = None
@@ -105,7 +106,7 @@ def format_data(data):
     durations = torch.zeros(attn_mask.shape[0], attn_mask.shape[2])
     for idx, am in enumerate(attn_mask):
         # compute raw durations
-        c_idxs = am[:, :text_lengths[idx], :mel_lengths[idx]].max(1)[1]
+        c_idxs = am[:, : text_lengths[idx], : mel_lengths[idx]].max(1)[1]
         # c_idxs, counts = torch.unique_consecutive(c_idxs, return_counts=True)
         c_idxs, counts = torch.unique(c_idxs, return_counts=True)
         dur = torch.ones([text_lengths[idx]]).to(counts.dtype)
@@ -115,8 +116,10 @@ def format_data(data):
         extra_frames = dur.sum() - mel_lengths[idx]
         largest_idxs = torch.argsort(-dur)[:extra_frames]
         dur[largest_idxs] -= 1
-        assert dur.sum() == mel_lengths[idx], f" [!] total duration {dur.sum()} vs spectrogram length {mel_lengths[idx]}"
-        durations[idx, :text_lengths[idx]] = dur
+        assert (
+            dur.sum() == mel_lengths[idx]
+        ), f" [!] total duration {dur.sum()} vs spectrogram length {mel_lengths[idx]}"
+        durations[idx, : text_lengths[idx]] = dur
     # dispatch data to GPU
     if use_cuda:
         text_input = text_input.cuda(non_blocking=True)
@@ -127,19 +130,27 @@ def format_data(data):
             speaker_c = speaker_c.cuda(non_blocking=True)
         attn_mask = attn_mask.cuda(non_blocking=True)
         durations = durations.cuda(non_blocking=True)
-    return text_input, text_lengths, mel_input, mel_lengths, speaker_c,\
-         avg_text_length, avg_spec_length, attn_mask, durations, item_idx
+    return (
+        text_input,
+        text_lengths,
+        mel_input,
+        mel_lengths,
+        speaker_c,
+        avg_text_length,
+        avg_spec_length,
+        attn_mask,
+        durations,
+        item_idx,
+    )
 
 
-def train(data_loader, model, criterion, optimizer, scheduler,
-          ap, global_step, epoch):
+def train(data_loader, model, criterion, optimizer, scheduler, ap, global_step, epoch):
 
     model.train()
     epoch_time = 0
     keep_avg = KeepAverage()
     if use_cuda:
-        batch_n_iter = int(
-            len(data_loader.dataset) / (c.batch_size * num_gpus))
+        batch_n_iter = int(len(data_loader.dataset) / (c.batch_size * num_gpus))
     else:
         batch_n_iter = int(len(data_loader.dataset) / c.batch_size)
     end_time = time.time()
@@ -149,8 +160,18 @@ def train(data_loader, model, criterion, optimizer, scheduler,
         start_time = time.time()
 
         # format data
-        text_input, text_lengths, mel_targets, mel_lengths, speaker_c,\
-            avg_text_length, avg_spec_length, _, dur_target, _ = format_data(data)
+        (
+            text_input,
+            text_lengths,
+            mel_targets,
+            mel_lengths,
+            speaker_c,
+            avg_text_length,
+            avg_spec_length,
+            _,
+            dur_target,
+            _,
+        ) = format_data(data)
 
         loader_time = time.time() - end_time
 
@@ -160,23 +181,24 @@ def train(data_loader, model, criterion, optimizer, scheduler,
         # forward pass model
         with torch.cuda.amp.autocast(enabled=c.mixed_precision):
             decoder_output, dur_output, alignments = model.forward(
-                text_input, text_lengths, mel_lengths, dur_target, g=speaker_c)
+                text_input, text_lengths, mel_lengths, dur_target, g=speaker_c
+            )
 
             # compute loss
-            loss_dict = criterion(decoder_output, mel_targets, mel_lengths, dur_output, torch.log(1 + dur_target), text_lengths)
+            loss_dict = criterion(
+                decoder_output, mel_targets, mel_lengths, dur_output, torch.log(1 + dur_target), text_lengths
+            )
 
         # backward pass with loss scaling
         if c.mixed_precision:
-            scaler.scale(loss_dict['loss']).backward()
+            scaler.scale(loss_dict["loss"]).backward()
             scaler.unscale_(optimizer)
-            grad_norm = torch.nn.utils.clip_grad_norm_(model.parameters(),
-                                                       c.grad_clip)
+            grad_norm = torch.nn.utils.clip_grad_norm_(model.parameters(), c.grad_clip)
             scaler.step(optimizer)
             scaler.update()
         else:
-            loss_dict['loss'].backward()
-            grad_norm = torch.nn.utils.clip_grad_norm_(model.parameters(),
-                                                       c.grad_clip)
+            loss_dict["loss"].backward()
+            grad_norm = torch.nn.utils.clip_grad_norm_(model.parameters(), c.grad_clip)
             optimizer.step()
 
         # setup lr
@@ -184,21 +206,21 @@ def train(data_loader, model, criterion, optimizer, scheduler,
             scheduler.step()
 
         # current_lr
-        current_lr = optimizer.param_groups[0]['lr']
+        current_lr = optimizer.param_groups[0]["lr"]
 
         # compute alignment error (the lower the better )
         align_error = 1 - alignment_diagonal_score(alignments, binary=True)
-        loss_dict['align_error'] = align_error
+        loss_dict["align_error"] = align_error
 
         step_time = time.time() - start_time
         epoch_time += step_time
 
         # aggregate losses from processes
         if num_gpus > 1:
-            loss_dict['loss_l1'] = reduce_tensor(loss_dict['loss_l1'].data, num_gpus)
-            loss_dict['loss_ssim'] = reduce_tensor(loss_dict['loss_ssim'].data, num_gpus)
-            loss_dict['loss_dur'] = reduce_tensor(loss_dict['loss_dur'].data, num_gpus)
-            loss_dict['loss'] = reduce_tensor(loss_dict['loss'] .data, num_gpus)
+            loss_dict["loss_l1"] = reduce_tensor(loss_dict["loss_l1"].data, num_gpus)
+            loss_dict["loss_ssim"] = reduce_tensor(loss_dict["loss_ssim"].data, num_gpus)
+            loss_dict["loss_dur"] = reduce_tensor(loss_dict["loss_dur"].data, num_gpus)
+            loss_dict["loss"] = reduce_tensor(loss_dict["loss"].data, num_gpus)
 
         # detach loss values
         loss_dict_new = dict()
@@ -212,41 +234,43 @@ def train(data_loader, model, criterion, optimizer, scheduler,
         # update avg stats
         update_train_values = dict()
         for key, value in loss_dict.items():
-            update_train_values['avg_' + key] = value
-        update_train_values['avg_loader_time'] = loader_time
-        update_train_values['avg_step_time'] = step_time
+            update_train_values["avg_" + key] = value
+        update_train_values["avg_loader_time"] = loader_time
+        update_train_values["avg_step_time"] = step_time
         keep_avg.update_values(update_train_values)
 
         # print training progress
         if global_step % c.print_step == 0:
             log_dict = {
-
                 "avg_spec_length": [avg_spec_length, 1],  # value, precision
                 "avg_text_length": [avg_text_length, 1],
                 "step_time": [step_time, 4],
                 "loader_time": [loader_time, 2],
                 "current_lr": current_lr,
             }
-            c_logger.print_train_step(batch_n_iter, num_iter, global_step,
-                                      log_dict, loss_dict, keep_avg.avg_values)
+            c_logger.print_train_step(batch_n_iter, num_iter, global_step, log_dict, loss_dict, keep_avg.avg_values)
 
         if args.rank == 0:
             # Plot Training Iter Stats
             # reduce TB load
             if global_step % c.tb_plot_step == 0:
-                iter_stats = {
-                    "lr": current_lr,
-                    "grad_norm": grad_norm,
-                    "step_time": step_time
-                }
+                iter_stats = {"lr": current_lr, "grad_norm": grad_norm, "step_time": step_time}
                 iter_stats.update(loss_dict)
                 tb_logger.tb_train_iter_stats(global_step, iter_stats)
 
             if global_step % c.save_step == 0:
                 if c.checkpoint:
                     # save model
-                    save_checkpoint(model, optimizer, global_step, epoch, 1, OUT_PATH, model_characters,
-                                    model_loss=loss_dict['loss'])
+                    save_checkpoint(
+                        model,
+                        optimizer,
+                        global_step,
+                        epoch,
+                        1,
+                        OUT_PATH,
+                        model_characters,
+                        model_loss=loss_dict["loss"],
+                    )
 
                 # wait all kernels to be completed
                 torch.cuda.synchronize()
@@ -267,9 +291,7 @@ def train(data_loader, model, criterion, optimizer, scheduler,
 
                 # Sample audio
                 train_audio = ap.inv_melspectrogram(pred_spec.T)
-                tb_logger.tb_train_audios(global_step,
-                                          {'TrainAudio': train_audio},
-                                          c.audio["sample_rate"])
+                tb_logger.tb_train_audios(global_step, {"TrainAudio": train_audio}, c.audio["sample_rate"])
         end_time = time.time()
 
     # print epoch stats
@@ -296,16 +318,18 @@ def evaluate(data_loader, model, criterion, ap, global_step, epoch):
             start_time = time.time()
 
             # format data
-            text_input, text_lengths, mel_targets, mel_lengths, speaker_c,\
-                _, _, _, dur_target, _ = format_data(data)
+            text_input, text_lengths, mel_targets, mel_lengths, speaker_c, _, _, _, dur_target, _ = format_data(data)
 
             # forward pass model
             with torch.cuda.amp.autocast(enabled=c.mixed_precision):
                 decoder_output, dur_output, alignments = model.forward(
-                    text_input, text_lengths, mel_lengths, dur_target, g=speaker_c)
+                    text_input, text_lengths, mel_lengths, dur_target, g=speaker_c
+                )
 
                 # compute loss
-                loss_dict = criterion(decoder_output, mel_targets, mel_lengths, dur_output, torch.log(1 + dur_target), text_lengths)
+                loss_dict = criterion(
+                    decoder_output, mel_targets, mel_lengths, dur_output, torch.log(1 + dur_target), text_lengths
+                )
 
             # step time
             step_time = time.time() - start_time
@@ -313,14 +337,14 @@ def evaluate(data_loader, model, criterion, ap, global_step, epoch):
 
             # compute alignment score
             align_error = 1 - alignment_diagonal_score(alignments, binary=True)
-            loss_dict['align_error'] = align_error
+            loss_dict["align_error"] = align_error
 
             # aggregate losses from processes
             if num_gpus > 1:
-                loss_dict['loss_l1'] = reduce_tensor(loss_dict['loss_l1'].data, num_gpus)
-                loss_dict['loss_ssim'] = reduce_tensor(loss_dict['loss_ssim'].data, num_gpus)
-                loss_dict['loss_dur'] = reduce_tensor(loss_dict['loss_dur'].data, num_gpus)
-                loss_dict['loss'] = reduce_tensor(loss_dict['loss'] .data, num_gpus)
+                loss_dict["loss_l1"] = reduce_tensor(loss_dict["loss_l1"].data, num_gpus)
+                loss_dict["loss_ssim"] = reduce_tensor(loss_dict["loss_ssim"].data, num_gpus)
+                loss_dict["loss_dur"] = reduce_tensor(loss_dict["loss_dur"].data, num_gpus)
+                loss_dict["loss"] = reduce_tensor(loss_dict["loss"].data, num_gpus)
 
             # detach loss values
             loss_dict_new = dict()
@@ -334,7 +358,7 @@ def evaluate(data_loader, model, criterion, ap, global_step, epoch):
             # update avg stats
             update_train_values = dict()
             for key, value in loss_dict.items():
-                update_train_values['avg_' + key] = value
+                update_train_values["avg_" + key] = value
             keep_avg.update_values(update_train_values)
 
             if c.print_eval:
@@ -350,13 +374,12 @@ def evaluate(data_loader, model, criterion, ap, global_step, epoch):
             eval_figures = {
                 "prediction": plot_spectrogram(pred_spec, ap, output_fig=False),
                 "ground_truth": plot_spectrogram(gt_spec, ap, output_fig=False),
-                "alignment": plot_alignment(align_img, output_fig=False)
+                "alignment": plot_alignment(align_img, output_fig=False),
             }
 
             # Sample audio
             eval_audio = ap.inv_melspectrogram(pred_spec.T)
-            tb_logger.tb_eval_audios(global_step, {"ValAudio": eval_audio},
-                                     c.audio["sample_rate"])
+            tb_logger.tb_eval_audios(global_step, {"ValAudio": eval_audio}, c.audio["sample_rate"])
 
             # Plot Validation Stats
             tb_logger.tb_eval_stats(global_step, keep_avg.avg_values)
@@ -369,7 +392,7 @@ def evaluate(data_loader, model, criterion, ap, global_step, epoch):
                 "Be a voice, not an echo.",
                 "I'm sorry Dave. I'm afraid I can't do that.",
                 "This cake is great. It's so delicious and moist.",
-                "Prior to November 22, 1963."
+                "Prior to November 22, 1963.",
             ]
         else:
             with open(c.test_sentences_file, "r") as f:
@@ -381,7 +404,9 @@ def evaluate(data_loader, model, criterion, ap, global_step, epoch):
         print(" | > Synthesizing test sentences")
         if c.use_speaker_embedding:
             if c.use_external_speaker_embedding_file:
-                speaker_embedding = speaker_mapping[list(speaker_mapping.keys())[randrange(len(speaker_mapping)-1)]]['embedding']
+                speaker_embedding = speaker_mapping[list(speaker_mapping.keys())[randrange(len(speaker_mapping) - 1)]][
+                    "embedding"
+                ]
                 speaker_id = None
             else:
                 speaker_id = 0
@@ -403,25 +428,22 @@ def evaluate(data_loader, model, criterion, ap, global_step, epoch):
                     speaker_embedding=speaker_embedding,
                     style_wav=style_wav,
                     truncated=False,
-                    enable_eos_bos_chars=c.enable_eos_bos_chars, #pylint: disable=unused-argument
+                    enable_eos_bos_chars=c.enable_eos_bos_chars,  # pylint: disable=unused-argument
                     use_griffin_lim=True,
-                    do_trim_silence=False)
+                    do_trim_silence=False,
+                )
 
                 file_path = os.path.join(AUDIO_PATH, str(global_step))
                 os.makedirs(file_path, exist_ok=True)
-                file_path = os.path.join(file_path,
-                                         "TestSentence_{}.wav".format(idx))
+                file_path = os.path.join(file_path, "TestSentence_{}.wav".format(idx))
                 ap.save_wav(wav, file_path)
-                test_audios['{}-audio'.format(idx)] = wav
-                test_figures['{}-prediction'.format(idx)] = plot_spectrogram(
-                    postnet_output, ap)
-                test_figures['{}-alignment'.format(idx)] = plot_alignment(
-                    alignment)
-            except: #pylint: disable=bare-except
+                test_audios["{}-audio".format(idx)] = wav
+                test_figures["{}-prediction".format(idx)] = plot_spectrogram(postnet_output, ap)
+                test_figures["{}-alignment".format(idx)] = plot_alignment(alignment)
+            except:  # pylint: disable=bare-except
                 print(" !! Error creating Test Sentence -", idx)
                 traceback.print_exc()
-        tb_logger.tb_test_audios(global_step, test_audios,
-                                 c.audio['sample_rate'])
+        tb_logger.tb_test_audios(global_step, test_audios, c.audio["sample_rate"])
         tb_logger.tb_test_figures(global_step, test_figures)
     return keep_avg.avg_values
 
@@ -432,13 +454,12 @@ def main(args):  # pylint: disable=redefined-outer-name
     global meta_data_train, meta_data_eval, symbols, phonemes, model_characters, speaker_mapping
     # Audio processor
     ap = AudioProcessor(**c.audio)
-    if 'characters' in c.keys():
+    if "characters" in c.keys():
         symbols, phonemes = make_symbols(**c.characters)
 
     # DISTRUBUTED
     if num_gpus > 1:
-        init_distributed(args.rank, num_gpus, args.group_id,
-                         c.distributed["backend"], c.distributed["url"])
+        init_distributed(args.rank, num_gpus, args.group_id, c.distributed["backend"], c.distributed["url"])
 
     # set model characters
     model_characters = phonemes if c.use_phonemes else symbols
@@ -448,10 +469,10 @@ def main(args):  # pylint: disable=redefined-outer-name
     meta_data_train, meta_data_eval = load_meta_data(c.datasets, eval_split=True)
 
     # set the portion of the data used for training if set in config.json
-    if 'train_portion' in c.keys():
-        meta_data_train = meta_data_train[:int(len(meta_data_train) * c.train_portion)]
-    if 'eval_portion' in c.keys():
-        meta_data_eval = meta_data_eval[:int(len(meta_data_eval) * c.eval_portion)]
+    if "train_portion" in c.keys():
+        meta_data_train = meta_data_train[: int(len(meta_data_train) * c.train_portion)]
+    if "eval_portion" in c.keys():
+        meta_data_eval = meta_data_eval[: int(len(meta_data_eval) * c.eval_portion)]
 
     # parse speakers
     num_speakers, speaker_embedding_dim, speaker_mapping = parse_speakers(c, args, meta_data_train, OUT_PATH)
@@ -463,26 +484,25 @@ def main(args):  # pylint: disable=redefined-outer-name
 
     if args.restore_path:
         print(f" > Restoring from {os.path.basename(args.restore_path)} ...")
-        checkpoint = torch.load(args.restore_path, map_location='cpu')
+        checkpoint = torch.load(args.restore_path, map_location="cpu")
         try:
             # TODO: fix optimizer init, model.cuda() needs to be called before
             # optimizer restore
-            optimizer.load_state_dict(checkpoint['optimizer'])
+            optimizer.load_state_dict(checkpoint["optimizer"])
             if c.reinit_layers:
                 raise RuntimeError
-            model.load_state_dict(checkpoint['model'])
-        except: #pylint: disable=bare-except
+            model.load_state_dict(checkpoint["model"])
+        except:  # pylint: disable=bare-except
             print(" > Partial model initialization.")
             model_dict = model.state_dict()
-            model_dict = set_init_dict(model_dict, checkpoint['model'], c)
+            model_dict = set_init_dict(model_dict, checkpoint["model"], c)
             model.load_state_dict(model_dict)
             del model_dict
 
         for group in optimizer.param_groups:
-            group['initial_lr'] = c.lr
-        print(" > Model restored from step %d" % checkpoint['step'],
-              flush=True)
-        args.restore_step = checkpoint['step']
+            group["initial_lr"] = c.lr
+        print(" > Model restored from step %d" % checkpoint["step"], flush=True)
+        args.restore_step = checkpoint["step"]
     else:
         args.restore_step = 0
 
@@ -495,9 +515,7 @@ def main(args):  # pylint: disable=redefined-outer-name
         model = DDP_th(model, device_ids=[args.rank])
 
     if c.noam_schedule:
-        scheduler = NoamLR(optimizer,
-                           warmup_steps=c.warmup_steps,
-                           last_epoch=args.restore_step - 1)
+        scheduler = NoamLR(optimizer, warmup_steps=c.warmup_steps, last_epoch=args.restore_step - 1)
     else:
         scheduler = None
 
@@ -505,16 +523,14 @@ def main(args):  # pylint: disable=redefined-outer-name
     print("\n > Model has {} parameters".format(num_params), flush=True)
 
     if args.restore_step == 0 or not args.best_path:
-        best_loss = float('inf')
+        best_loss = float("inf")
         print(" > Starting with inf best loss.")
     else:
-        print(" > Restoring best loss from "
-              f"{os.path.basename(args.best_path)} ...")
-        best_loss = torch.load(args.best_path,
-                               map_location='cpu')['model_loss']
+        print(" > Restoring best loss from " f"{os.path.basename(args.best_path)} ...")
+        best_loss = torch.load(args.best_path, map_location="cpu")["model_loss"]
         print(f" > Starting with loaded last best loss {best_loss}.")
-    keep_all_best = c.get('keep_all_best', False)
-    keep_after = c.get('keep_after', 10000)  # void if keep_all_best False
+    keep_all_best = c.get("keep_all_best", False)
+    keep_after = c.get("keep_after", 10000)  # void if keep_all_best False
 
     # define dataloaders
     train_loader = setup_loader(ap, 1, is_val=False, verbose=True)
@@ -523,24 +539,32 @@ def main(args):  # pylint: disable=redefined-outer-name
     global_step = args.restore_step
     for epoch in range(0, c.epochs):
         c_logger.print_epoch_start(epoch, c.epochs)
-        train_avg_loss_dict, global_step = train(train_loader, model, criterion, optimizer,
-                                                 scheduler, ap, global_step,
-                                                 epoch)
-        eval_avg_loss_dict = evaluate(eval_loader, model, criterion, ap,
-                                      global_step, epoch)
+        train_avg_loss_dict, global_step = train(
+            train_loader, model, criterion, optimizer, scheduler, ap, global_step, epoch
+        )
+        eval_avg_loss_dict = evaluate(eval_loader, model, criterion, ap, global_step, epoch)
         c_logger.print_epoch_end(epoch, eval_avg_loss_dict)
-        target_loss = train_avg_loss_dict['avg_loss']
+        target_loss = train_avg_loss_dict["avg_loss"]
         if c.run_eval:
-            target_loss = eval_avg_loss_dict['avg_loss']
-        best_loss = save_best_model(target_loss, best_loss, model, optimizer,
-                                    global_step, epoch, c.r, OUT_PATH, model_characters,
-                                    keep_all_best=keep_all_best, keep_after=keep_after)
+            target_loss = eval_avg_loss_dict["avg_loss"]
+        best_loss = save_best_model(
+            target_loss,
+            best_loss,
+            model,
+            optimizer,
+            global_step,
+            epoch,
+            c.r,
+            OUT_PATH,
+            model_characters,
+            keep_all_best=keep_all_best,
+            keep_after=keep_after,
+        )
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     args = parse_arguments(sys.argv)
-    c, OUT_PATH, AUDIO_PATH, c_logger, tb_logger = process_args(
-        args, model_type='tts')
+    c, OUT_PATH, AUDIO_PATH, c_logger, tb_logger = process_args(args, model_class="tts")
 
     try:
         main(args)
