@@ -13,11 +13,12 @@ class TacotronConfig(BaseTTSConfig):
     model: str = "tacotron"
     gst: GSTConfig = None
     # model specific params
-    r: int = None
+    r: int = 2
     gradual_training: List = None
     memory_size: int = -1
     prenet_type: str = "original"
     prenet_dropout: bool = True
+    prenet_dropout_at_inference: bool = False
     stopnet: bool = True
     separate_stopnet: bool = True
     stopnet_pos_weight: float = 10.0
@@ -58,7 +59,7 @@ class TacotronConfig(BaseTTSConfig):
     decoder_diff_spec_alpha: float = 0.25
     decoder_ssim_alpha: float = 0.25
     postnet_ssim_alpha: float = 0.25
-    ga_alpha: float = 0.0
+    ga_alpha: float = 5.0
 
     def check_values(
         self,
