@@ -7,31 +7,32 @@ import numpy as np
 import torch
 import tqdm
 from torch.utils.data import Dataset
-from TTS.tts.utils.data import (prepare_data, prepare_stop_target,
-                                prepare_tensor)
-from TTS.tts.utils.text import (pad_with_eos_bos, phoneme_to_sequence,
-                                text_to_sequence)
+
+from TTS.tts.utils.data import prepare_data, prepare_stop_target, prepare_tensor
+from TTS.tts.utils.text import pad_with_eos_bos, phoneme_to_sequence, text_to_sequence
 
 
 class MyDataset(Dataset):
-    def __init__(self,
-                 outputs_per_step,
-                 text_cleaner,
-                 compute_linear_spec,
-                 ap,
-                 meta_data,
-                 tp=None,
-                 add_blank=False,
-                 batch_group_size=0,
-                 min_seq_len=0,
-                 max_seq_len=float("inf"),
-                 use_phonemes=True,
-                 phoneme_cache_path=None,
-                 phoneme_language="en-us",
-                 enable_eos_bos=False,
-                 speaker_mapping=None,
-                 use_noise_augment=False,
-                 verbose=False):
+    def __init__(
+        self,
+        outputs_per_step,
+        text_cleaner,
+        compute_linear_spec,
+        ap,
+        meta_data,
+        tp=None,
+        add_blank=False,
+        batch_group_size=0,
+        min_seq_len=0,
+        max_seq_len=float("inf"),
+        use_phonemes=True,
+        phoneme_cache_path=None,
+        phoneme_language="en-us",
+        enable_eos_bos=False,
+        speaker_mapping=None,
+        use_noise_augment=False,
+        verbose=False,
+    ):
         """
         Args:
             outputs_per_step (int): number of time frames predicted per step.
@@ -53,7 +54,7 @@ class MyDataset(Dataset):
             use_noise_augment (bool): enable adding random noise to wav for augmentation.
             verbose (bool): print diagnostic information.
         """
-        super(MyDataset, self).__init__()
+        super().__init__()
         self.batch_group_size = batch_group_size
         self.items = meta_data
         self.outputs_per_step = outputs_per_step
@@ -88,45 +89,42 @@ class MyDataset(Dataset):
 
     @staticmethod
     def load_np(filename):
-        data = np.load(filename).astype('float32')
+        data = np.load(filename).astype("float32")
         return data
 
     @staticmethod
-    def _generate_and_cache_phoneme_sequence(text, cache_path, cleaners,
-                                             language, tp, add_blank):
+    def _generate_and_cache_phoneme_sequence(text, cache_path, cleaners, language, tp, add_blank):
         """generate a phoneme sequence from text.
         since the usage is for subsequent caching, we never add bos and
         eos chars here. Instead we add those dynamically later; based on the
         config option."""
-        phonemes = phoneme_to_sequence(text, [cleaners],
-                                       language=language,
-                                       enable_eos_bos=False,
-                                       tp=tp,
-                                       add_blank=add_blank)
+        phonemes = phoneme_to_sequence(
+            text, [cleaners], language=language, enable_eos_bos=False, tp=tp, add_blank=add_blank
+        )
         phonemes = np.asarray(phonemes, dtype=np.int32)
         np.save(cache_path, phonemes)
         return phonemes
 
     @staticmethod
-    def _load_or_generate_phoneme_sequence(wav_file, text, phoneme_cache_path,
-                                           enable_eos_bos, cleaners, language,
-                                           tp, add_blank):
+    def _load_or_generate_phoneme_sequence(
+        wav_file, text, phoneme_cache_path, enable_eos_bos, cleaners, language, tp, add_blank
+    ):
         file_name = os.path.splitext(os.path.basename(wav_file))[0]
 
         # different names for normal phonemes and with blank chars.
-        file_name_ext = '_blanked_phoneme.npy' if add_blank else '_phoneme.npy'
-        cache_path = os.path.join(phoneme_cache_path,
-                                  file_name + file_name_ext)
+        file_name_ext = "_blanked_phoneme.npy" if add_blank else "_phoneme.npy"
+        cache_path = os.path.join(phoneme_cache_path, file_name + file_name_ext)
         try:
             phonemes = np.load(cache_path)
         except FileNotFoundError:
             phonemes = MyDataset._generate_and_cache_phoneme_sequence(
-                text, cache_path, cleaners, language, tp, add_blank)
+                text, cache_path, cleaners, language, tp, add_blank
+            )
         except (ValueError, IOError):
-            print(" [!] failed loading phonemes for {}. "
-                  "Recomputing.".format(wav_file))
+            print(" [!] failed loading phonemes for {}. " "Recomputing.".format(wav_file))
             phonemes = MyDataset._generate_and_cache_phoneme_sequence(
-                text, cache_path, cleaners, language, tp, add_blank)
+                text, cache_path, cleaners, language, tp, add_blank
+            )
         if enable_eos_bos:
             phonemes = pad_with_eos_bos(phonemes, tp=tp)
             phonemes = np.asarray(phonemes, dtype=np.int32)
@@ -150,15 +148,20 @@ class MyDataset(Dataset):
         if not self.input_seq_computed:
             if self.use_phonemes:
                 text = self._load_or_generate_phoneme_sequence(
-                    wav_file, text, self.phoneme_cache_path,
-                    self.enable_eos_bos, self.cleaners, self.phoneme_language,
-                    self.tp, self.add_blank)
+                    wav_file,
+                    text,
+                    self.phoneme_cache_path,
+                    self.enable_eos_bos,
+                    self.cleaners,
+                    self.phoneme_language,
+                    self.tp,
+                    self.add_blank,
+                )
 
             else:
-                text = np.asarray(text_to_sequence(text, [self.cleaners],
-                                                   tp=self.tp,
-                                                   add_blank=self.add_blank),
-                                  dtype=np.int32)
+                text = np.asarray(
+                    text_to_sequence(text, [self.cleaners], tp=self.tp, add_blank=self.add_blank), dtype=np.int32
+                )
 
         assert text.size > 0, self.items[idx][1]
         assert wav.size > 0, self.items[idx][1]
@@ -173,12 +176,12 @@ class MyDataset(Dataset):
             return self.load_data(100)
 
         sample = {
-            'text': text,
-            'wav': wav,
-            'attn': attn,
-            'item_idx': self.items[idx][1],
-            'speaker_name': speaker_name,
-            'wav_file_name': os.path.basename(wav_file)
+            "text": text,
+            "wav": wav,
+            "attn": attn,
+            "item_idx": self.items[idx][1],
+            "speaker_name": speaker_name,
+            "wav_file_name": os.path.basename(wav_file),
         }
         return sample
 
@@ -187,8 +190,7 @@ class MyDataset(Dataset):
         item = args[0]
         func_args = args[1]
         text, wav_file, *_ = item
-        phonemes = MyDataset._load_or_generate_phoneme_sequence(
-            wav_file, text, *func_args)
+        phonemes = MyDataset._load_or_generate_phoneme_sequence(wav_file, text, *func_args)
         return phonemes
 
     def compute_input_seq(self, num_workers=0):
@@ -199,17 +201,19 @@ class MyDataset(Dataset):
                 print(" | > Computing input sequences ...")
             for idx, item in enumerate(tqdm.tqdm(self.items)):
                 text, *_ = item
-                sequence = np.asarray(text_to_sequence(
-                    text, [self.cleaners],
-                    tp=self.tp,
-                    add_blank=self.add_blank),
-                                      dtype=np.int32)
+                sequence = np.asarray(
+                    text_to_sequence(text, [self.cleaners], tp=self.tp, add_blank=self.add_blank), dtype=np.int32
+                )
                 self.items[idx][0] = sequence
 
         else:
             func_args = [
-                self.phoneme_cache_path, self.enable_eos_bos, self.cleaners,
-                self.phoneme_language, self.tp, self.add_blank
+                self.phoneme_cache_path,
+                self.enable_eos_bos,
+                self.cleaners,
+                self.phoneme_language,
+                self.tp,
+                self.add_blank,
             ]
             if self.verbose:
                 print(" | > Computing phonemes ...")
@@ -220,10 +224,11 @@ class MyDataset(Dataset):
             else:
                 with Pool(num_workers) as p:
                     phonemes = list(
-                        tqdm.tqdm(p.imap(MyDataset._phoneme_worker,
-                                         [[item, func_args]
-                                          for item in self.items]),
-                                  total=len(self.items)))
+                        tqdm.tqdm(
+                            p.imap(MyDataset._phoneme_worker, [[item, func_args] for item in self.items]),
+                            total=len(self.items),
+                        )
+                    )
                     for idx, p in enumerate(phonemes):
                         self.items[idx][0] = p
 
@@ -255,8 +260,10 @@ class MyDataset(Dataset):
             print(" | > Min length sequence: {}".format(np.min(lengths)))
             print(" | > Avg length sequence: {}".format(np.mean(lengths)))
             print(
-                " | > Num. instances discarded by max-min (max={}, min={}) seq limits: {}"
-                .format(self.max_seq_len, self.min_seq_len, len(ignored)))
+                " | > Num. instances discarded by max-min (max={}, min={}) seq limits: {}".format(
+                    self.max_seq_len, self.min_seq_len, len(ignored)
+                )
+            )
             print(" | > Batch group size: {}.".format(self.batch_group_size))
 
     def __len__(self):
@@ -267,11 +274,11 @@ class MyDataset(Dataset):
 
     def collate_fn(self, batch):
         r"""
-            Perform preprocessing and create a final data batch:
-            1. Sort batch instances by text-length
-            2. Convert Audio signal to Spectrograms.
-            3. PAD sequences wrt r.
-            4. Load to Torch.
+        Perform preprocessing and create a final data batch:
+        1. Sort batch instances by text-length
+        2. Convert Audio signal to Spectrograms.
+        3. PAD sequences wrt r.
+        4. Load to Torch.
         """
 
         # Puts each data field into a tensor with outer dimension batch size
@@ -280,44 +287,29 @@ class MyDataset(Dataset):
             text_lenghts = np.array([len(d["text"]) for d in batch])
 
             # sort items with text input length for RNN efficiency
-            text_lenghts, ids_sorted_decreasing = torch.sort(
-                torch.LongTensor(text_lenghts), dim=0, descending=True)
+            text_lenghts, ids_sorted_decreasing = torch.sort(torch.LongTensor(text_lenghts), dim=0, descending=True)
 
-            wav = [batch[idx]['wav'] for idx in ids_sorted_decreasing]
-            item_idxs = [
-                batch[idx]['item_idx'] for idx in ids_sorted_decreasing
-            ]
-            text = [batch[idx]['text'] for idx in ids_sorted_decreasing]
+            wav = [batch[idx]["wav"] for idx in ids_sorted_decreasing]
+            item_idxs = [batch[idx]["item_idx"] for idx in ids_sorted_decreasing]
+            text = [batch[idx]["text"] for idx in ids_sorted_decreasing]
 
-            speaker_name = [
-                batch[idx]['speaker_name'] for idx in ids_sorted_decreasing
-            ]
+            speaker_name = [batch[idx]["speaker_name"] for idx in ids_sorted_decreasing]
             # get speaker embeddings
             if self.speaker_mapping is not None:
-                wav_files_names = [
-                    batch[idx]['wav_file_name']
-                    for idx in ids_sorted_decreasing
-                ]
-                speaker_embedding = [
-                    self.speaker_mapping[w]['embedding']
-                    for w in wav_files_names
-                ]
+                wav_files_names = [batch[idx]["wav_file_name"] for idx in ids_sorted_decreasing]
+                speaker_embedding = [self.speaker_mapping[w]["embedding"] for w in wav_files_names]
             else:
                 speaker_embedding = None
             # compute features
-            mel = [self.ap.melspectrogram(w).astype('float32') for w in wav]
+            mel = [self.ap.melspectrogram(w).astype("float32") for w in wav]
 
             mel_lengths = [m.shape[1] for m in mel]
 
             # compute 'stop token' targets
-            stop_targets = [
-                np.array([0.] * (mel_len - 1) + [1.])
-                for mel_len in mel_lengths
-            ]
+            stop_targets = [np.array([0.0] * (mel_len - 1) + [1.0]) for mel_len in mel_lengths]
 
             # PAD stop targets
-            stop_targets = prepare_stop_target(stop_targets,
-                                               self.outputs_per_step)
+            stop_targets = prepare_stop_target(stop_targets, self.outputs_per_step)
 
             # PAD sequences with longest instance in the batch
             text = prepare_data(text).astype(np.int32)
@@ -340,9 +332,7 @@ class MyDataset(Dataset):
 
             # compute linear spectrogram
             if self.compute_linear_spec:
-                linear = [
-                    self.ap.spectrogram(w).astype('float32') for w in wav
-                ]
+                linear = [self.ap.spectrogram(w).astype("float32") for w in wav]
                 linear = prepare_tensor(linear, self.outputs_per_step)
                 linear = linear.transpose(0, 2, 1)
                 assert mel.shape[1] == linear.shape[1]
@@ -351,8 +341,8 @@ class MyDataset(Dataset):
                 linear = None
 
             # collate attention alignments
-            if batch[0]['attn'] is not None:
-                attns = [batch[idx]['attn'].T for idx in ids_sorted_decreasing]
+            if batch[0]["attn"] is not None:
+                attns = [batch[idx]["attn"].T for idx in ids_sorted_decreasing]
                 for idx, attn in enumerate(attns):
                     pad2 = mel.shape[1] - attn.shape[1]
                     pad1 = text.shape[1] - attn.shape[0]
@@ -362,8 +352,24 @@ class MyDataset(Dataset):
                 attns = torch.FloatTensor(attns).unsqueeze(1)
             else:
                 attns = None
-            return text, text_lenghts, speaker_name, linear, mel, mel_lengths, \
-                   stop_targets, item_idxs, speaker_embedding, attns
+            return (
+                text,
+                text_lenghts,
+                speaker_name,
+                linear,
+                mel,
+                mel_lengths,
+                stop_targets,
+                item_idxs,
+                speaker_embedding,
+                attns,
+            )
 
-        raise TypeError(("batch must contain tensors, numbers, dicts or lists;\
-                         found {}".format(type(batch[0]))))
+        raise TypeError(
+            (
+                "batch must contain tensors, numbers, dicts or lists;\
+                         found {}".format(
+                    type(batch[0])
+                )
+            )
+        )
