@@ -275,7 +275,7 @@ class AudioProcessor(object):
         else:
             D = self._stft(y)
         S = self._amp_to_db(np.abs(D))
-        return self.normalize(S)
+        return self.normalize(S).astype(np.float32)
 
     def melspectrogram(self, y):
         if self.preemphasis != 0:
@@ -283,7 +283,7 @@ class AudioProcessor(object):
         else:
             D = self._stft(y)
         S = self._amp_to_db(self._linear_to_mel(np.abs(D)))
-        return self.normalize(S)
+        return self.normalize(S).astype(np.float32)
 
     def inv_spectrogram(self, spectrogram):
         """Converts spectrogram to waveform using librosa"""
@@ -366,7 +366,7 @@ class AudioProcessor(object):
         return len(wav)
 
     def trim_silence(self, wav):
-        """ Trim silent parts with a threshold and 0.01 sec margin """
+        """Trim silent parts with a threshold and 0.01 sec margin"""
         margin = int(self.sample_rate * 0.01)
         wav = wav[margin:-margin]
         return librosa.effects.trim(wav, top_db=self.trim_db, frame_length=self.win_length, hop_length=self.hop_length)[
