@@ -107,6 +107,7 @@ class ModelManager(object):
             os.makedirs(output_path, exist_ok=True)
             print(f" > Downloading model to {output_path}")
             output_stats_path = os.path.join(output_path, "scale_stats.npy")
+            output_speakers_path = os.path.join(output_path, "speakers.json")
             # download files to the output path
             if self._check_dict_key(model_item, "github_rls_url"):
                 # download from github release
@@ -119,7 +120,7 @@ class ModelManager(object):
                 if self._check_dict_key(model_item, "stats_file"):
                     self._download_gdrive_file(model_item["stats_file"], output_stats_path)
 
-            # set the scale_path.npy file path in the model config.json
+            # update the scale_path.npy file path in the model config.json
             if self._check_dict_key(model_item, "stats_file") or os.path.exists(output_stats_path):
                 # set scale stats path in config.json
                 config_path = output_config_path
@@ -127,6 +128,14 @@ class ModelManager(object):
                 config["audio"]["stats_path"] = output_stats_path
                 with open(config_path, "w") as jf:
                     json.dump(config, jf)
+            # update the speakers.json file path in the model config.json to the current path
+            if os.path.exists(output_speakers_path):
+                # set scale stats path in config.json
+                config_path = output_config_path
+                config = load_config(config_path)
+                config["external_speaker_embedding_file"] = output_speakers_path
+                with open(config_path, "w") as jf:
+                    json.dump(config, jf)
         return output_model_path, output_config_path, model_item
 
     def _download_gdrive_file(self, gdrive_idx, output):
